Skip to contents

Selects a cache directory from the specified path. If only one cache subdirectory exists, it is returned automatically; if multiple are found, an interactive menu is presented for the user to choose.

Usage

ChooseCache(directory, ...)

Arguments

directory

Path to the parent directory containing cache subdirectories.

...

Unused, reserved for future extensions.

Value

The path to the selected cache directory (character string).

Examples

if (FALSE) { # interactive()
if (FALSE) { # \dontrun{
cache_path <- ChooseCache("./Scissor_res")
} # }
}