Selects a cache directory from the specified path. If only one cache subdirectory exists, it is returned automatically; if multiple are found, an interactive menu is presented for the user to choose.
See also
Other cache_config:
CacheSetHere(),
CheckCache(),
LoadCache(),
WriteCache(),
WriteCacheMeta()