Perform SIDISH Screening Analysis
Arguments
- matched_bulk
Matrix or data frame of preprocessed bulk RNA-seq expression data (genes x samples). Column names must match names/IDs in
phenotype.- sc_data
A Seurat object containing scRNA-seq data to be screened.
- phenotype
Phenotype data, either: - Patient survival Data frame with row names matching
matched_bulkcolumns, colnames named "time" and "status"- label_type
Character specifying phenotype label type
- phenotype_class
Type of phenotypic outcome (must be consistent with input data): -
"survival": Survival infomation- assay
Seurat assay name, default:
"RNA".- sidish_param
Parameters adjusting SIDISH. Use
SigBridgeR:::SIDISHParamSet()to see all available parameters and fetch default values.- env_params
Parameters adjusting python environment. Use
SigBridgeR:::SIDISHEnvSet()to see all available parameters and fetch default values.- ...
Additional arguments passed to the function. Common parameters include:
- verbose
Logical. Whether to print verbose output (default:
TRUE).
Value
A named list containing:
- scRNA_data
Modified single-cell data object with integrated screening results.
See also
Other screen_method:
DoDEGAS(),
DoLP_SGL(),
DoPIPET(),
DoSCIPAC(),
DoScissor(),
DoscAB(),
DoscPAS(),
DoscPP()