Skip to contents

Reads a cached R object from disk. The file format is determined by the file extension:

If the file was originally saved in .qs2 format but qs2 is not installed on the current machine, a clear error message is shown with installation instructions.

Usage

LoadCache(file, ...)

Arguments

file

Character string. Path to the cache file to load.

...

Additional arguments (must be empty, checked by rlang::check_dots_empty0()).

Value

The cached R object.

Examples

if (FALSE) { # \dontrun{
result <- LoadCache("Scissor_res/survival_2025_01_01/result.qs2")
feature_df <- LoadCache("Scissor_res/survival_2025_01_01/feature_table.csv")
} # }