Reads a cached R object from disk. The file format is determined by the file extension:
.qs2: loaded viaqs2::qs_read().RData/.rds: loaded viareadRDS().csv: loaded viadata.table::fread()
If the file was originally saved in .qs2 format but qs2 is
not installed on the current machine, a clear error message is shown with
installation instructions.
Arguments
- file
Character string. Path to the cache file to load.
- ...
Additional arguments (must be empty, checked by
rlang::check_dots_empty0()).
See also
Other cache_config:
CacheSetHere(),
CheckCache(),
ChooseCache(),
WriteCache(),
WriteCacheMeta()